@@ -5,6 +5,8 @@ context("grouped_lm")
 testthat::test_that(
   desc = "grouped_lm works",
   code = {
+    testthat::skip_if(getRversion() < "3.6")
+
     testthat::skip_on_cran()
     testthat::skip_on_travis()
     testthat::skip_on_appveyor()
@@ -26,7 +28,7 @@ testthat::test_that(
     set.seed(123)
     df2 <- groupedstats::grouped_lm(
       data = mtcars,
-      grouping.vars = cyl,
+      grouping.vars = "cyl",
       formula = mpg ~ am * wt,
       output = "augment"
     )
@@ -36,7 +38,7 @@ testthat::test_that(
     set.seed(123)
     df3 <- groupedstats::grouped_lm(
       data = diamonds,
-      grouping.vars = c(cut, color),
+      grouping.vars = c("cut", color),
       formula = price ~ carat * clarity,
       output = "glance"
     )
